Fix a segfault in the engine caused by performing a recursive-delete on a
volume when the volume and its underlying objects are not active in the
kernel.

Apply with:
cd /usr/src/evms-2.1.1
patch -p1 < recursive_delete.patch
make
make install

--- evms-2.1.1a/engine/commit.c	2 Oct 2003 20:24:05 -0000
+++ evms-2.1.1b/engine/commit.c	10 Oct 2003 15:11:05 -0000
@@ -399,17 +399,14 @@
 
 	int rc = 0;
 	logical_volume_t * volume = (logical_volume_t *) object;
-	storage_object_t * working_top_object;
 
 	LOG_PROC_ENTRY();
 
 	LOG_DEBUG("Request to delete volume %s.\n", volume->name);
 
-	rc = get_working_top_object(volume, &working_top_object);
 	if (rc == 0) {
 		if (!(volume->flags & VOLFLAG_COMPATIBILITY) &&
-		    (working_top_object->object_type != EVMS_OBJECT) &&
-		    (volume->flags & VOLFLAG_ACTIVE)) {
+		    (volume->flags & (VOLFLAG_ACTIVE | VOLFLAG_NEEDS_DEACTIVATE))) {
 			dm_deactivate_volume(volume);
 		}
 	}
--- evms-2.1.1a/engine/common.c	2 Oct 2003 19:36:37 -0000
+++ evms-2.1.1b/engine/common.c	10 Oct 2003 15:11:05 -0000
@@ -1351,6 +1351,7 @@
 					 * it is one for making the object into an EVMS
 					 * volume.  Remove the feature header and kill
 					 * the sectors so that it won't be found again.
+					 * Mark that the volume needs to be deactivated.
 					 */
 					if (obj->feature_header != NULL) {
 						LOG_DEBUG("Removing feature headers from object %s.\n", obj->name);
@@ -1359,6 +1360,7 @@
 						if (rc == 0) {
 							engine_free(obj->feature_header);
 							obj->feature_header = NULL;
+							volume->flags |= VOLFLAG_NEEDS_DEACTIVATE;
 
 						} else {
 							LOG_SERIOUS("add_sectors_to_kill_list() returned error code %d when called to wipe out volume feature header on volume %s.\n", rc, volume->name);
